SariskaMediaTransportMethodChannel class

A class implementing the SariskaMediaTransportInterface.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
localTracks List<JitsiLocalTrack>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createLocalTracks(Map<String, dynamic> options, LocalTrackCallback callback) → void
Creates local tracks with the given options and invokes the callback function.
override
getName() String
Retrieves the name of the Sariska Media Transport implementation.
override
getPlatformVersion() Future<String?>
Retrieves the platform version.
override
initializeSdk() → void
Initializes the Sariska Media Transport SDK.
override
jitsiConnection(String token, String roomName, bool isNightly) Connection
Creates a connection to the Jitsi server.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

initialized bool
getter/setter pair
localTrackCallback LocalTrackCallback
Callback function for receiving local tracks.
getter/setter pair

Constants

eventChannel → const EventChannel
methodChannel → const MethodChannel
The method channel used to interact with the native platform.